/*
 * Copyright (c) 2017 Uber Technologies, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef JAEGERTRACING_NET_HTTP_ERROR_H
#define JAEGERTRACING_NET_HTTP_ERROR_H

#include <sstream>
#include <stdexcept>
#include <string>

namespace jaegertracing {
namespace net {
namespace http {

class ParseError : public std::invalid_argument {
  public:
    using invalid_argument::invalid_argument;

    static ParseError make(const std::string& expected,
                           const std::string& actual)
    {
        std::ostringstream oss;
        oss << "Parse error, expected " << expected << ", encountered \""
            << actual << '"';
        return ParseError(oss.str());
    }
};

}  // namespace http
}  // namespace net
}  // namespace jaegertracing

#endif  // JAEGERTRACING_NET_HTTP_ERROR_H
